/*
	MyDrawView.cpp
	Dan Parks Sydow
	1997
	
	Based on source code from:
	HelloView.cpp
	Copyright 1995 Be Incorporated, All Rights Reserved.
*/

#ifndef MY_DRAW_VIEW_H
#include "MyDrawView.h"
#endif

MyDrawView::MyDrawView(BRect rect, char *name)
    : BView(rect, name, B_FOLLOW_ALL, B_WILL_DRAW)
{
}


void MyDrawView::AttachedToWindow() 
{
    SetFont(be_bold_font); 
    SetFontSize(24);
}


void MyDrawView::Draw(BRect)
{
   BRect    aRect;
// Cut out the rgb_color variables.
   pattern  stripePattern = {0xcc, 0x66, 0x33, 0x99, 0xcc, 0x66, 0x33, 0x99};

// Omit the SetHighColor() and SetLowColor() calls so result is in black and white. 
// Shows up better in Magnify screen dump.
// And, this section is on patterns, not color

   aRect.Set(10, 10, 110, 110);
   FillRect(aRect, stripePattern);
}

// A pattern designates which of the 64 bits (8 rows of 8 bits) in an 8 pixel by 8 pixel
// are displayed using the high color and which are displayed using the low color. Thus the 
// pattern itself doesn't designate *what* colors constitute its makeup. Instead, a pattern 
// definition marks each of its 64 bits as a 1 to display the high color and a 0 to display 
// the low color. If all bits are set to 1, or on, then the pattern is the same as the B_SOLID_HIGH
// pattern. Here's how Be defines that constant:
//
//     const pattern B_SOLID_HIGH = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff}
//
// If all bits are set to 0, or off, then the pattern is the same as the B_SOLID_LOW pattern.
// Here's how Be defines that constant:
//
//     const pattern B_SOLID_LOW = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
//
// If all bits are set to 0, or off, then the pattern is the same as the B_SOLID_LOW pattern.
// Here's how Be defines that constant:
//
//     const pattern B_MIXED_COLORS = {0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55}
//
//      Note: *provide details of why the above produces a checkboard pattern.*
//          hexadecimal a = decimal 10 = binary 1010
//          hexadecimal 5 = decimal 5  = binary 0101
//      Thus aa fills the one byte of one row with    : 10101010
//      and 55 fills the one byte of the next row with: 01010101
//
// The previous example (Drawing 1) set the high color to red and the low color to blue, then
// filled a rectangle using the B_MIXED_COLORS pattern. That produced what appears to be a solid 
// purple color. Because the B_MIXED_COLORS pattern is a checkboard pattern of alternating high
// color/low color, the color isn't at all solid -- it's actually made up of alternating blue 
// and red pixels. To highlight this fact, Figure 5-x shows the Drawing 2 window, with the Magnify 
// utility program window also open. The cursor is over the purple square, so those bits are shown 
// in the Magnify window.
//
// Defining your own pattern begins by declaring a variable of type pattern:
//
//     pattern  myPattern;
//
// The pattern data type is an array of 8 bytes. Its definition looks like this:
//
//     typedef  struct {
//        uchar  data[8];
//     } pattern;
//
// You set up the pattern by assigning a value of 1 or 0 to each of the 64 bits. You can do 
// that just as was shown for the Be-defined pattern constants -- initialize each of the eight 
// one byte fields of the pattern structure at the time the pattern is declared. Here's an 
// example:
//
//     pattern  stripePattern = {0xcc, 0x66, 0x33, 0x99, 0xcc, 0x66, 0x33, 0x99};
//
// START SIDE BAR: Patterns and Binary and Hexadecimal Values
//    You'll need to know a little about binary and hexadecimal numbers in order to properly 
// define a pattern. Figure 5-xW shows the 8-by-8 grid for the above pattern. To design the
// pattern I drew each high bit in a black and each low bit in white. A pattern only defines
// on and off, not color, so this technique works fine irrespective of the colors I'll be using
// when I draw with the pattern. Next, to the left of each row I write a 1 for each high bit in 
// that row and a 0 for each low bit in that row. Looking at four bits at a time, to the right of
// each row I write the hexadecimal equivalent. For the first row, 1100 in binary is 'c' in
// hexadecimal, so the pair is 'cc'. Compare the right column of hexadecimal values in Figure 5-xW
// to the initialization of the stripePattern variable above to see where the initialization 
// values came from.
// END SIDE BAR
//
// NOTE TO ME: Figure 5-xW should be an enlarged 8 by 8 grid that shows the pattern.
//      1100 1100     B B W W B B W W    cc
//      0110 0110     W B B W W B B W    66
//      0011 0011     W W B B W W B B    33
//      1001 1001     B W W B B W W B    99
//      1100 1100     B B W W B B W W    cc
//      0110 0110     W B B W W B B W    66
//      0011 0011     W W B B W W B B    33
//      1001 1001     B W W B B W W B    99
//
// The pattern can then be used in a call to any routine that requires a pattern as a parameter. 
// You've already seen this done with the BView member function FillRect(). In the the Drawing 1
// example the Be-defined constants were used as the second parameter. Here I use my own pattern
// variable diagonalStripePattern:
//
//     BRect    colorRect(10, 10, 110, 110);
//     pattern  stripePattern = {0xcc, 0x66, 0x33, 0x99, 0xcc, 0x66, 0x33, 0x99};
//
//     FillRect(colorRect, stripePattern);
//
// If I've previously made calls to the BView member functions SetHighColor() and SetLowColor()
// to define the high and low colors to be red and blue (as I did earlier), then the result 
// will be alternating red and blue diagonal lines. If the high and low colors are instead left
// at their default values of black and white, then the stripes will be in black and white.


