/*
	MyHelloWindow.cpp
	Dan Parks Sydow
	1997
	
	Based on source code from:
	HelloWindow.cpp
	Copyright 1995 Be Incorporated, All Rights Reserved.
*/

#ifndef _APPLICATION_H
#include <Application.h>
#endif
#ifndef MY_HELLO_WINDOW_H
#include "MyHelloWindow.h"
#endif

BRect  textNumCirclesRect(20.0, 40.0, 120.0, 60.0);
const char* textNumCirclesName = "TextNumCircles";
const char* textNumCirclesLabel = "Circles:";
const char* textNumCirclesText = "5";

BRect       checkBoxSetColorRect(20.0, 70.0, 150.0, 90.0);
const char* checkBoxSetColorName = "SetColor";
const char* checkBoxSetColorLabel = "Disable colors";

BRect  radioGroupRect(20.0, 100.0, 150.0, 160.0);
BRect  radioRedRect(0.0, 1.0, 150.0, 20.0);
const char* radioRedName = "RedRadio";
const char* radioRedLabel = "Red";
BRect  radioGreenRect(0.0, 21.0, 150.0, 40.0);
const char* radioGreenName = "GreenRadio";
const char* radioGreenLabel = "Green";
BRect  radioBlackRect(0.0, 41.0, 150.0, 60.0);
const char* radioBlackName = "BlackRadio";
const char* radioBlackLabel = "Black";

BRect  buttonDrawRect(20.0, 170.0, 110.0, 190.0);
const char* buttonDrawName = "Beep";
const char* buttonDrawLabel = "Draw";

MyHelloWindow::MyHelloWindow(BRect frame)
    : BWindow(frame, "My Hello", B_TITLED_WINDOW, B_NOT_RESIZABLE)
{
   // Add main view
    frame.OffsetTo(B_ORIGIN);
    fMyView = new MyDrawView(frame, "MyDrawView");
    AddChild(fMyView);

   // Add "Set color" check box
	fCheckBoxSetColor = new BCheckBox(checkBoxSetColorRect, 
									checkBoxSetColorName, 
									checkBoxSetColorLabel, 
									new BMessage(CHECKBOX_SET_COLOR_MSG));
	fMyView->AddChild(fCheckBoxSetColor);

    // Add "Draw" button
	fButtonDraw = new BButton(	buttonDrawRect, 
								buttonDrawName, 
								buttonDrawLabel, 
								new BMessage(BUTTON_DRAW_MSG));
	fMyView->AddChild(fButtonDraw);

    // Add "Number of circles" text box
	fTextNumCircles = new BTextControl(	textNumCirclesRect, 
								textNumCirclesName, 
								textNumCirclesLabel, 
								textNumCirclesText,
								new BMessage(TEXT_NUM_CIRCLES_MSG));
	fMyView->AddChild(fTextNumCircles);

   // Add radio button grouping view
	BView  *radioGroupView;
	
 	radioGroupView = new BView(radioGroupRect, "RadioGroupView", B_FOLLOW_ALL, B_WILL_DRAW);
    fMyView->AddChild(radioGroupView);

   // Add the "Red," "Green," and "Black" radio buttons
	fRadioRed = new BRadioButton(	radioRedRect, 
								radioRedName, 
								radioRedLabel, 
								new BMessage(RADIO_RED_MSG));
	radioGroupView->AddChild(fRadioRed);

	fRadioGreen = new BRadioButton(	radioGreenRect, 
								radioGreenName, 
								radioGreenLabel, 
								new BMessage(RADIO_GREEN_MSG));
	radioGroupView->AddChild(fRadioGreen);

	fRadioBlack = new BRadioButton(	radioBlackRect, 
								radioBlackName, 
								radioBlackLabel, 
								new BMessage(RADIO_BLACK_MSG));
	radioGroupView->AddChild(fRadioBlack);

	fRadioBlack->SetValue(B_CONTROL_ON);
	fNumCircles = 5;

    Show();
}


bool MyHelloWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return(TRUE);
}

// *** NEW
void MyHelloWindow::MessageReceived(BMessage* message)
{
	switch(message->what)
	{
		case BUTTON_DRAW_MSG:
			int32  i;
			BRect  areaRect(160.0, 70.0, 270.0, 180.0);			
			BRect  circleRect(160.0, 70.0, 210.0, 120.0);			
			const char *textBoxText;
			
		  	textBoxText = fTextNumCircles->Text();
            fNumCircles = (int32)textBoxText[0] - 48;
            
            if ((fNumCircles < 1) || (fNumCircles > 9))
               fNumCircles = 5; 
            
            fMyView->FillRect(areaRect, B_SOLID_LOW);
            
			for (i=1; i<=fNumCircles; i++) {
			   fMyView->StrokeEllipse(circleRect, B_SOLID_HIGH);
			   circleRect.OffsetBy(4.0, 4.0);
   			}
   			break;

		case CHECKBOX_SET_COLOR_MSG:
			int32  checkBoxState;
			
			checkBoxState = fCheckBoxSetColor->Value();
			if (checkBoxState == B_CONTROL_ON) {
				fRadioRed->SetEnabled(false);			
				fRadioGreen->SetEnabled(false);			
				fRadioBlack->SetEnabled(false);	
			}		
			else {
				fRadioRed->SetEnabled(true);			
				fRadioGreen->SetEnabled(true);			
				fRadioBlack->SetEnabled(true);		
			}	
			break;
	
		case RADIO_RED_MSG:
		  	fMyView->SetHighColor(255, 0, 0, 0);
		  	break;

		case RADIO_GREEN_MSG:
		  	fMyView->SetHighColor(0, 255, 0, 0);
		  	break;

		case RADIO_BLACK_MSG:
		  	fMyView->SetHighColor(0, 0, 0, 0);
		  	break;
		  	
		default:
			BWindow::MessageReceived(message);
	}
}
// *** NEW
