/*
	MyHelloWindow.cpp
	Dan Parks Sydow
	1997
	
	Based on source code from:
	HelloWindow.cpp
	Copyright 1995 Be Incorporated, All Rights Reserved.
*/

#ifndef _APPLICATION_H
#include <Application.h>
#endif
#ifndef MY_HELLO_WINDOW_H
#include "MyHelloWindow.h"
#endif

#define   MENU_BAR_HEIGHT   18.0


BRect       buttonBeepRect(15.0, 155.0, 110.0, 185.0);
const char* buttonBeepName = "BeepButton";
const char* buttonBeepLabel = "Beep ";


MyHelloWindow::MyHelloWindow(BRect frame)
    : BWindow(frame, "My Hello", B_TITLED_WINDOW, B_NOT_ZOOMABLE)
{
	frame.Set(130.0, MENU_BAR_HEIGHT + 10.0, 290.0, 190.0);
    fMyView = new MyDrawView(frame, "MyDrawView");
    AddChild(fMyView);

	fButtonBeep = new BButton(buttonBeepRect, buttonBeepName, 
							   buttonBeepLabel, new BMessage(BUTTON_BEEP_MSG));
	AddChild(fButtonBeep);           
    fButtonBeep->MakeDefault(true);

	BMenu		*menu;
	BMenuItem	*menuItem;
	BRect		menuBarRect;

	menuBarRect.Set(0.0, 0.0, 32000.0, MENU_BAR_HEIGHT);
	fMenuBar = new BMenuBar(menuBarRect, "MenuBar");
	AddChild(fMenuBar);
	
	menu = new BMenu("Audio");
	fMenuBar->AddItem(menu);
	menu->AddItem(new BMenuItem("Beep Once", new BMessage(MENU_BEEP_1_MSG), '1', B_COMMAND_KEY));
// if a menu item is to be initially marked, save a reference to the item when 
// creating it:
	menu->AddItem(menuItem = new BMenuItem("Beep Twice", new BMessage(MENU_BEEP_2_MSG), '2', B_COMMAND_KEY));
// now, the BMenuItem function SetMarked() can be invoked by the BMenuItem object menuItem:
    menuItem->SetMarked(true);

// If all of the items in a menu are to act as a related set of options, then set the
// menu to radio mode. This tells a menu that it may have only one item selected at any 
// given time. So all the items in the one menu should be related options. Selecting one 
// item checks it and unchecks all other menu items in that menu. Note that it is your
// responsibility to mark whichever item is to be initially marked. In this next snippet 
// I'm creating three menu items and adding them to a menu, setting the second item to be
// marked, and then setting the menu itself to radio mode. After the call to SetRadioMode(),
// the system becomes responsible for keeping track of the checking and unchecking of the 
// items in the menu.
	menu->SetRadioMode(true);
// **** NEW   end  set menu to radio mode, mark item
// **** NEW  new data member, set its value:
	fNumBeeps = 2;

    Show();
}


bool MyHelloWindow::QuitRequested()
{
    be_app->PostMessage(B_QUIT_REQUESTED);

    return(true);
}


void MyHelloWindow::MessageReceived(BMessage* message)
{

	switch(message->what)
	{
		case BUTTON_BEEP_MSG:
			// ********* NEW this was simply a call to beep() in previous example:
    		bigtime_t  microseconds = 1000000;  // one second
			int32      i;
			
			for (i = 1; i <= fNumBeeps; i++) 
			{
		  	   beep();
		  	   if (i != fNumBeeps)
   			      snooze(microseconds);
   			}
   			// ******** NEW  end new
 		  	break;

		case MENU_BEEP_1_MSG:
			// ******* NEW  this was a call to beep(). There was no fNumBeeps data member
		  	fNumBeeps = 1;
		  	break;

		// ***** NEW case section
		case MENU_BEEP_2_MSG:
		  	fNumBeeps = 2;
		  	break;
		// ***** NEW end new case section
		default:
			BWindow::MessageReceived(message);
	}
}
